@@ -15,6 +15,11 @@ if [[ ${KOLLA_INSTALL_TYPE} == "source" ]] && [[ ! -f ${SITE_PACKAGES}/openstack
         ${SITE_PACKAGES}/openstack_dashboard/local/local_settings.py
 fi
 
+if [[ -f /etc/openstack-dashboard/custom_local_settings ]] && [[ ! -f ${SITE_PACKAGES}/openstack_dashboard/local/custom_local_settings.py ]]; then
+    ln -s /etc/openstack-dashboard/custom_local_settings \
+        ${SITE_PACKAGES}/openstack_dashboard/local/custom_local_settings.py
+fi
+
 # Bootstrap and exit if KOLLA_BOOTSTRAP variable is set. This catches all cases
 # of the KOLLA_BOOTSTRAP variable being set, including empty.
 if [[ "${!KOLLA_BOOTSTRAP[@]}" ]]; then
@@ -30,7 +35,9 @@ function config_dashboard {
     ENABLE=$1
     SRC=$2
     DEST=$3
-    if [[ "${ENABLE}" == "yes" ]] && [[ ! -f "${DEST}" ]]; then
+    if [[ ! -f ${SRC} ]]; then
+        echo "WARNING: ${SRC} is required"
+    elif [[ "${ENABLE}" == "yes" ]] && [[ ! -f "${DEST}" ]]; then
         cp -a "${SRC}" "${DEST}"
         FORCE_GENERATE="yes"
     elif [[ "${ENABLE}" != "yes" ]] && [[ -f "${DEST}" ]]; then
@@ -72,6 +79,14 @@ function config_freezer_ui {
     done
 }
 
+function config_heat_dashboard {
+    for file in ${SITE_PACKAGES}/heat_dashboard/enabled/_*[^__].py; do
+        config_dashboard "${ENABLE_HEAT}" \
+            "${SITE_PACKAGES}/heat_dashboard/enabled/${file##*/}" \
+            "${SITE_PACKAGES}/openstack_dashboard/local/enabled/${file##*/}"
+    done
+}
+
 function config_ironic_dashboard {
     for file in ${SITE_PACKAGES}/ironic_ui/enabled/_*[^__].py; do
         config_dashboard "${ENABLE_IRONIC}" \
@@ -131,6 +146,12 @@ function config_neutron_lbaas {
         "${SITE_PACKAGES}/openstack_dashboard/local/enabled/_1481_project_ng_loadbalancersv2_panel.py"
 }
 
+function config_octavia_dashboard {
+    config_dashboard "${ENABLE_OCTAVIA}" \
+        "${SITE_PACKAGES}/octavia_dashboard/enabled/_1482_project_load_balancer_panel.py" \
+        "${SITE_PACKAGES}/openstack_dashboard/local/enabled/_1482_project_load_balancer_panel.py"
+}
+
 function config_sahara_dashboard {
     for file in ${SITE_PACKAGES}/sahara_dashboard/enabled/_*[^__].py; do
         config_dashboard "${ENABLE_SAHARA}" \
@@ -191,6 +212,14 @@ function config_trove_dashboard {
     done
 }
 
+function config_vitrage_dashboard {
+    for file in ${SITE_PACKAGES}/vitrage_dashboard/enabled/_*[^__].py; do
+        config_dashboard "${ENABLE_VITRAGE}" \
+            "${SITE_PACKAGES}/vitrage_dashboard/enabled/${file##*/}" \
+            "${SITE_PACKAGES}/openstack_dashboard/local/enabled/${file##*/}"
+    done
+}
+
 function config_watcher_dashboard {
     for file in ${SITE_PACKAGES}/watcher_dashboard/local/enabled/_*[^__].py; do
         config_dashboard "${ENABLE_WATCHER}" \
@@ -219,10 +248,26 @@ function config_zun_dashboard {
     done
 }
 
+# NOTE(jeffrey4l, niedbalski): The local_settings and custom_local_settings files
+# affect django-compress behavior, so re-generate the compressed
+# javascript and css if any of those setting files changed
+function settings_changed {
+    declare -A settings=( ['/etc/openstack-dashboard/local_settings']="/var/lib/kolla/.local_settings.md5sum.txt" ['/etc/openstack-dashboard/custom_local_settings']="/var/lib/kolla/.custom_local_settings.md5sum.txt")
+    declare -x changed=1
+    for path in "${!settings[@]}"; do
+        if [[ ! -f ${settings[$path]} || $(md5sum -c --status ${settings[$path]};echo $?) != 0 || ${FORCE_GENERATE} == "yes" ]]; then
+            changed=0
+            md5sum ${path} > ${settings[$path]}
+        fi
+    done
+    return ${changed}
+}
+
 config_cloudkitty_dashboard
 config_designate_dashboard
 config_fwaas_dashboard
 config_freezer_ui
+config_heat_dashboard
 config_ironic_dashboard
 config_karbor_dashboard
 config_magnum_dashboard
@@ -230,12 +275,14 @@ config_manila_ui
 config_mistral_dashboard
 config_murano_dashboard
 config_neutron_lbaas
+config_octavia_dashboard
 config_sahara_dashboard
 config_searchlight_ui
 config_senlin_dashboard
 config_solum_dashboard
 config_tacker_dashboard
 config_trove_dashboard
+config_vitrage_dashboard
 config_watcher_dashboard
 config_zaqar_dashboard
 config_zun_dashboard
@@ -250,12 +297,7 @@ else
     rm -rf /var/run/httpd/* /run/httpd/* /tmp/httpd*
 fi
 
-# NOTE(jeffrey4l): The local_settings file affect django-compress
-# behavior, so re-generate the compressed javascript and css if it
-# is changed
-MD5SUM_TXT_PATH="/var/lib/kolla/.local_settings.md5sum.txt"
-if [[ ! -f ${MD5SUM_TXT_PATH} || $(md5sum -c --status ${MD5SUM_TXT_PATH};echo $?) != 0 || ${FORCE_GENERATE} == "yes" ]]; then
-    md5sum /etc/openstack-dashboard/local_settings > ${MD5SUM_TXT_PATH}
+if settings_changed; then
     if [[ "${KOLLA_INSTALL_TYPE}" == "binary" ]]; then
         /usr/bin/manage.py collectstatic --noinput --clear
         /usr/bin/manage.py compress --force
