@@ -35,8 +35,3 @@ class Task(object):
     @abc.abstractmethod
     def run(self):
         pass
-
-    @staticmethod
-    def set_status(status):
-        # TODO(harlowja): remove this.
-        pass
